# Quadratic programming examples

Examples are roughly sorted from simple to complex. The basic ones are:

- [Quadratic program](quadratic_program.py)
- [Linear least squares](least_squares.py)
- [Box inequalities](box_inequalities.py)
- [Sparse linear least squares](sparse_least_squares.py)

For more advance use cases, check out:

- [Dual multipliers](dual_multipliers.py)

## Applications

Feel free to share yours in [Show and tell](https://github.com/qpsolvers/qpsolvers/discussions/categories/show-and-tell)!

- [Constrained linear regression](constrained_linear_regression.py)
- [Model predictive control for humanoid locomotion](model_predictive_control.py)
